@@ -62,6 +62,8 @@ gotoblas_t TABLE_NAME = {
  MAX(SBGEMM_DEFAULT_UNROLL_M, SBGEMM_DEFAULT_UNROLL_N),
 #endif
 
+  SBGEMM_ALIGN_K,
+
   sbstobf16_k_BARCELONA, sbdtobf16_k_BARCELONA, sbf16tos_k_BARCELONA, dbf16tod_k_BARCELONA,
 
   samax_k_BARCELONA,  samin_k_BARCELONA,  smax_k_BARCELONA,  smin_k_BARCELONA,
@@ -135,9 +137,14 @@ gotoblas_t TABLE_NAME = {
   0,
 #endif
 
-#if (BUILD_SINGLE==1 ) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
   samax_k_BARCELONA,  samin_k_BARCELONA,  smax_k_BARCELONA,  smin_k_BARCELONA,
-  isamax_k_BARCELONA, isamin_k_BARCELONA, ismax_k_BARCELONA, ismin_k_BARCELONA,
+#endif
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+  isamax_k_BARCELONA,
+#endif 
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
+  isamin_k_BARCELONA, ismax_k_BARCELONA, ismin_k_BARCELONA,
   snrm2_k_BARCELONA,  sasum_k_BARCELONA,
 #endif 
 #if BUILD_SINGLE == 1  
@@ -156,8 +163,10 @@ gotoblas_t TABLE_NAME = {
   sswap_k_BARCELONA,
   sgemv_n_BARCELONA,  sgemv_t_BARCELONA,
 #endif
-#if BUILD_SINGLE == 1  
+#if BUILD_SINGLE == 1
   sger_k_BARCELONA,
+#endif
+#if BUILD_SINGLE == 1  
   ssymv_L_BARCELONA, ssymv_U_BARCELONA,
 #endif
 
@@ -176,7 +185,7 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_BARCELONA, sgemm_otcopy_BARCELONA,
 #endif
 
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || BUILD_DOUBLE == 1 || BUILD_COMPLEX == 1
 #ifdef SMALL_MATRIX_OPT
   sgemm_small_matrix_permit_BARCELONA,
   sgemm_small_kernel_nn_BARCELONA, sgemm_small_kernel_nt_BARCELONA, sgemm_small_kernel_tn_BARCELONA, sgemm_small_kernel_tt_BARCELONA,
@@ -184,7 +193,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX == 1)
   strsm_kernel_LN_BARCELONA, strsm_kernel_LT_BARCELONA, strsm_kernel_RN_BARCELONA, strsm_kernel_RT_BARCELONA,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strsm_iunucopy_BARCELONA, strsm_iunncopy_BARCELONA, strsm_iutucopy_BARCELONA, strsm_iutncopy_BARCELONA,
@@ -196,7 +205,7 @@ gotoblas_t TABLE_NAME = {
   strsm_ounucopy_BARCELONA, strsm_ounncopy_BARCELONA, strsm_outucopy_BARCELONA, strsm_outncopy_BARCELONA,
   strsm_olnucopy_BARCELONA, strsm_olnncopy_BARCELONA, strsm_oltucopy_BARCELONA, strsm_oltncopy_BARCELONA,
 #endif
-#if BUILD_SINGLE == 1
+#if (BUILD_SINGLE==1)
   strmm_kernel_RN_BARCELONA, strmm_kernel_RT_BARCELONA, strmm_kernel_LN_BARCELONA, strmm_kernel_LT_BARCELONA,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strmm_iunucopy_BARCELONA, strmm_iunncopy_BARCELONA, strmm_iutucopy_BARCELONA, strmm_iutncopy_BARCELONA,
@@ -213,8 +222,6 @@ gotoblas_t TABLE_NAME = {
   ssymm_outcopy_BARCELONA, ssymm_oltcopy_BARCELONA,
 #endif
   ssymm_outcopy_BARCELONA, ssymm_oltcopy_BARCELONA,
-#endif
-#if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)
 #ifndef NO_LAPACK
   sneg_tcopy_BARCELONA, slaswp_ncopy_BARCELONA,
 #else
@@ -222,7 +229,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   0, 0, 0,
   DGEMM_DEFAULT_UNROLL_M, DGEMM_DEFAULT_UNROLL_N,
 #ifdef DGEMM_DEFAULT_UNROLL_MN
@@ -233,7 +240,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   damax_k_BARCELONA,  damin_k_BARCELONA,  dmax_k_BARCELONA,  dmin_k_BARCELONA,
   idamax_k_BARCELONA, idamin_k_BARCELONA, idmax_k_BARCELONA, idmin_k_BARCELONA,
   dnrm2_k_BARCELONA, dasum_k_BARCELONA,
@@ -241,13 +248,13 @@ gotoblas_t TABLE_NAME = {
 #if  (BUILD_DOUBLE==1)  
   dsum_k_BARCELONA,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dcopy_k_BARCELONA, ddot_k_BARCELONA,
 #endif
 #if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)  
   dsdot_k_BARCELONA,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   drot_k_BARCELONA,
   daxpy_k_BARCELONA,
   dscal_k_BARCELONA, 
@@ -259,7 +266,7 @@ gotoblas_t TABLE_NAME = {
   dsymv_L_BARCELONA,  dsymv_U_BARCELONA,
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dgemm_kernel_BARCELONA, dgemm_beta_BARCELONA,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dgemm_incopy_BARCELONA, dgemm_itcopy_BARCELONA,
@@ -269,12 +276,14 @@ gotoblas_t TABLE_NAME = {
   dgemm_oncopy_BARCELONA, dgemm_otcopy_BARCELONA,
 #endif
 
-#if  (BUILD_DOUBLE==1)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
 #ifdef SMALL_MATRIX_OPT
   dgemm_small_matrix_permit_BARCELONA,
   dgemm_small_kernel_nn_BARCELONA, dgemm_small_kernel_nt_BARCELONA, dgemm_small_kernel_tn_BARCELONA, dgemm_small_kernel_tt_BARCELONA,
   dgemm_small_kernel_b0_nn_BARCELONA, dgemm_small_kernel_b0_nt_BARCELONA, dgemm_small_kernel_b0_tn_BARCELONA, dgemm_small_kernel_b0_tt_BARCELONA,
 #endif
+#endif
+#if  (BUILD_DOUBLE==1)   
   dtrsm_kernel_LN_BARCELONA, dtrsm_kernel_LT_BARCELONA, dtrsm_kernel_RN_BARCELONA, dtrsm_kernel_RT_BARCELONA,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_BARCELONA, dtrsm_iunncopy_BARCELONA, dtrsm_iutucopy_BARCELONA, dtrsm_iutncopy_BARCELONA,
@@ -364,7 +373,7 @@ gotoblas_t TABLE_NAME = {
 
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   0, 0, 0,
   CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N,
 #ifdef CGEMM_DEFAULT_UNROLL_MN
@@ -372,18 +381,23 @@ gotoblas_t TABLE_NAME = {
 #else
  MAX(CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N),
 #endif
-  camax_k_BARCELONA, camin_k_BARCELONA, icamax_k_BARCELONA, icamin_k_BARCELONA,
+#if (BUILD_COMPLEX)
+  camax_k_BARCELONA, camin_k_BARCELONA,
 #endif
 #if (BUILD_COMPLEX)
+  icamax_k_BARCELONA, 
+#endif
+#if (BUILD_COMPLEX)
+  icamin_k_BARCELONA,
   cnrm2_k_BARCELONA, casum_k_BARCELONA, csum_k_BARCELONA,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
-  ccopy_k_BARCELONA,  cdotu_k_BARCELONA, cdotc_k_BARCELONA,
+#if (BUILD_COMPLEX)
+  ccopy_k_BARCELONA, cdotu_k_BARCELONA, cdotc_k_BARCELONA,
 #endif
 #if (BUILD_COMPLEX)
  csrot_k_BARCELONA,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   caxpy_k_BARCELONA,
   caxpyc_k_BARCELONA, 
   cscal_k_BARCELONA, 
@@ -397,7 +411,7 @@ gotoblas_t TABLE_NAME = {
   csymv_L_BARCELONA, csymv_U_BARCELONA,
   chemv_L_BARCELONA, chemv_U_BARCELONA, chemv_M_BARCELONA, chemv_V_BARCELONA,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   cgemm_kernel_n_BARCELONA, cgemm_kernel_l_BARCELONA, cgemm_kernel_r_BARCELONA, cgemm_kernel_b_BARCELONA,
   cgemm_beta_BARCELONA,
 #if CGEMM_DEFAULT_UNROLL_M != CGEMM_DEFAULT_UNROLL_N
@@ -432,6 +446,7 @@ gotoblas_t TABLE_NAME = {
   ctrsm_ounucopy_BARCELONA,  ctrsm_ounncopy_BARCELONA,  ctrsm_outucopy_BARCELONA,  ctrsm_outncopy_BARCELONA,
   ctrsm_olnucopy_BARCELONA,  ctrsm_olnncopy_BARCELONA,  ctrsm_oltucopy_BARCELONA,  ctrsm_oltncopy_BARCELONA,
 #endif
+#endif
 #if (BUILD_COMPLEX)
 
   ctrmm_kernel_RN_BARCELONA,  ctrmm_kernel_RT_BARCELONA,  ctrmm_kernel_RR_BARCELONA,  ctrmm_kernel_RC_BARCELONA,
@@ -522,7 +537,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
 #ifndef NO_LAPACK
   cneg_tcopy_BARCELONA,
   
@@ -866,7 +881,7 @@ gotoblas_t TABLE_NAME = {
   cgeadd_k_BARCELONA,
 #endif
 #if BUILD_COMPLEX16==1
-  zgeadd_k_BARCELONA
+  zgeadd_k_BARCELONA,
 #endif
 };
 
@@ -878,7 +893,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX==1
@@ -891,10 +906,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_q = SBGEMM_DEFAULT_Q;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_q = SGEMM_DEFAULT_Q;
 #endif
-#if BUILD_DOUBLE== 1
+#if BUILD_DOUBLE== 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_q = DGEMM_DEFAULT_Q;
 #endif
 #if BUILD_COMPLEX== 1
@@ -907,10 +922,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_r = SBGEMM_DEFAULT_R;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_r = SGEMM_DEFAULT_R;
 #endif
-#if BUILD_DOUBLE==1 
+#if BUILD_DOUBLE==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_r = DGEMM_DEFAULT_R;
 #endif
 #if BUILD_COMPLEX==1
@@ -1313,7 +1328,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  64 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  32 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1337,7 +1352,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  96 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  48 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1361,7 +1376,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 256;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 128;
 #endif
 #if BUILD_COMPLEX==1
@@ -1385,7 +1400,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE ==1 
+#if BUILD_DOUBLE ==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1
@@ -1409,7 +1424,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  92 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE==1
+#if BUILD_DOUBLE==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  46 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1433,7 +1448,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1457,7 +1472,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1482,7 +1497,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1506,7 +1521,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1554,7 +1569,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1579,7 +1594,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 224 +  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 112 +  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX
@@ -1603,7 +1618,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1627,7 +1642,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1651,7 +1666,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1675,7 +1690,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1700,7 +1715,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1724,7 +1739,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1748,7 +1763,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1773,7 +1788,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if  (BUILD_DOUBLE==1)
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if (BUILD_COMPLEX==1)
