@@ -62,6 +62,8 @@ gotoblas_t TABLE_NAME = {
  MAX(SBGEMM_DEFAULT_UNROLL_M, SBGEMM_DEFAULT_UNROLL_N),
 #endif
 
+  SBGEMM_ALIGN_K,
+
   sbstobf16_k_BULLDOZER, sbdtobf16_k_BULLDOZER, sbf16tos_k_BULLDOZER, dbf16tod_k_BULLDOZER,
 
   samax_k_BULLDOZER,  samin_k_BULLDOZER,  smax_k_BULLDOZER,  smin_k_BULLDOZER,
@@ -135,9 +137,14 @@ gotoblas_t TABLE_NAME = {
   0,
 #endif
 
-#if (BUILD_SINGLE==1 ) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
   samax_k_BULLDOZER,  samin_k_BULLDOZER,  smax_k_BULLDOZER,  smin_k_BULLDOZER,
-  isamax_k_BULLDOZER, isamin_k_BULLDOZER, ismax_k_BULLDOZER, ismin_k_BULLDOZER,
+#endif
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+  isamax_k_BULLDOZER,
+#endif 
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
+  isamin_k_BULLDOZER, ismax_k_BULLDOZER, ismin_k_BULLDOZER,
   snrm2_k_BULLDOZER,  sasum_k_BULLDOZER,
 #endif 
 #if BUILD_SINGLE == 1  
@@ -156,8 +163,10 @@ gotoblas_t TABLE_NAME = {
   sswap_k_BULLDOZER,
   sgemv_n_BULLDOZER,  sgemv_t_BULLDOZER,
 #endif
-#if BUILD_SINGLE == 1  
+#if BUILD_SINGLE == 1
   sger_k_BULLDOZER,
+#endif
+#if BUILD_SINGLE == 1  
   ssymv_L_BULLDOZER, ssymv_U_BULLDOZER,
 #endif
 
@@ -176,7 +185,7 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_BULLDOZER, sgemm_otcopy_BULLDOZER,
 #endif
 
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || BUILD_DOUBLE == 1 || BUILD_COMPLEX == 1
 #ifdef SMALL_MATRIX_OPT
   sgemm_small_matrix_permit_BULLDOZER,
   sgemm_small_kernel_nn_BULLDOZER, sgemm_small_kernel_nt_BULLDOZER, sgemm_small_kernel_tn_BULLDOZER, sgemm_small_kernel_tt_BULLDOZER,
@@ -184,7 +193,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX == 1)
   strsm_kernel_LN_BULLDOZER, strsm_kernel_LT_BULLDOZER, strsm_kernel_RN_BULLDOZER, strsm_kernel_RT_BULLDOZER,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strsm_iunucopy_BULLDOZER, strsm_iunncopy_BULLDOZER, strsm_iutucopy_BULLDOZER, strsm_iutncopy_BULLDOZER,
@@ -196,7 +205,7 @@ gotoblas_t TABLE_NAME = {
   strsm_ounucopy_BULLDOZER, strsm_ounncopy_BULLDOZER, strsm_outucopy_BULLDOZER, strsm_outncopy_BULLDOZER,
   strsm_olnucopy_BULLDOZER, strsm_olnncopy_BULLDOZER, strsm_oltucopy_BULLDOZER, strsm_oltncopy_BULLDOZER,
 #endif
-#if BUILD_SINGLE == 1
+#if (BUILD_SINGLE==1)
   strmm_kernel_RN_BULLDOZER, strmm_kernel_RT_BULLDOZER, strmm_kernel_LN_BULLDOZER, strmm_kernel_LT_BULLDOZER,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strmm_iunucopy_BULLDOZER, strmm_iunncopy_BULLDOZER, strmm_iutucopy_BULLDOZER, strmm_iutncopy_BULLDOZER,
@@ -213,8 +222,6 @@ gotoblas_t TABLE_NAME = {
   ssymm_outcopy_BULLDOZER, ssymm_oltcopy_BULLDOZER,
 #endif
   ssymm_outcopy_BULLDOZER, ssymm_oltcopy_BULLDOZER,
-#endif
-#if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)
 #ifndef NO_LAPACK
   sneg_tcopy_BULLDOZER, slaswp_ncopy_BULLDOZER,
 #else
@@ -222,7 +229,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   0, 0, 0,
   DGEMM_DEFAULT_UNROLL_M, DGEMM_DEFAULT_UNROLL_N,
 #ifdef DGEMM_DEFAULT_UNROLL_MN
@@ -233,7 +240,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   damax_k_BULLDOZER,  damin_k_BULLDOZER,  dmax_k_BULLDOZER,  dmin_k_BULLDOZER,
   idamax_k_BULLDOZER, idamin_k_BULLDOZER, idmax_k_BULLDOZER, idmin_k_BULLDOZER,
   dnrm2_k_BULLDOZER, dasum_k_BULLDOZER,
@@ -241,13 +248,13 @@ gotoblas_t TABLE_NAME = {
 #if  (BUILD_DOUBLE==1)  
   dsum_k_BULLDOZER,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dcopy_k_BULLDOZER, ddot_k_BULLDOZER,
 #endif
 #if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)  
   dsdot_k_BULLDOZER,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   drot_k_BULLDOZER,
   daxpy_k_BULLDOZER,
   dscal_k_BULLDOZER, 
@@ -259,7 +266,7 @@ gotoblas_t TABLE_NAME = {
   dsymv_L_BULLDOZER,  dsymv_U_BULLDOZER,
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dgemm_kernel_BULLDOZER, dgemm_beta_BULLDOZER,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dgemm_incopy_BULLDOZER, dgemm_itcopy_BULLDOZER,
@@ -269,12 +276,14 @@ gotoblas_t TABLE_NAME = {
   dgemm_oncopy_BULLDOZER, dgemm_otcopy_BULLDOZER,
 #endif
 
-#if  (BUILD_DOUBLE==1)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
 #ifdef SMALL_MATRIX_OPT
   dgemm_small_matrix_permit_BULLDOZER,
   dgemm_small_kernel_nn_BULLDOZER, dgemm_small_kernel_nt_BULLDOZER, dgemm_small_kernel_tn_BULLDOZER, dgemm_small_kernel_tt_BULLDOZER,
   dgemm_small_kernel_b0_nn_BULLDOZER, dgemm_small_kernel_b0_nt_BULLDOZER, dgemm_small_kernel_b0_tn_BULLDOZER, dgemm_small_kernel_b0_tt_BULLDOZER,
 #endif
+#endif
+#if  (BUILD_DOUBLE==1)   
   dtrsm_kernel_LN_BULLDOZER, dtrsm_kernel_LT_BULLDOZER, dtrsm_kernel_RN_BULLDOZER, dtrsm_kernel_RT_BULLDOZER,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_BULLDOZER, dtrsm_iunncopy_BULLDOZER, dtrsm_iutucopy_BULLDOZER, dtrsm_iutncopy_BULLDOZER,
@@ -364,7 +373,7 @@ gotoblas_t TABLE_NAME = {
 
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   0, 0, 0,
   CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N,
 #ifdef CGEMM_DEFAULT_UNROLL_MN
@@ -372,18 +381,23 @@ gotoblas_t TABLE_NAME = {
 #else
  MAX(CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N),
 #endif
-  camax_k_BULLDOZER, camin_k_BULLDOZER, icamax_k_BULLDOZER, icamin_k_BULLDOZER,
+#if (BUILD_COMPLEX)
+  camax_k_BULLDOZER, camin_k_BULLDOZER,
 #endif
 #if (BUILD_COMPLEX)
+  icamax_k_BULLDOZER, 
+#endif
+#if (BUILD_COMPLEX)
+  icamin_k_BULLDOZER,
   cnrm2_k_BULLDOZER, casum_k_BULLDOZER, csum_k_BULLDOZER,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
-  ccopy_k_BULLDOZER,  cdotu_k_BULLDOZER, cdotc_k_BULLDOZER,
+#if (BUILD_COMPLEX)
+  ccopy_k_BULLDOZER, cdotu_k_BULLDOZER, cdotc_k_BULLDOZER,
 #endif
 #if (BUILD_COMPLEX)
  csrot_k_BULLDOZER,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   caxpy_k_BULLDOZER,
   caxpyc_k_BULLDOZER, 
   cscal_k_BULLDOZER, 
@@ -397,7 +411,7 @@ gotoblas_t TABLE_NAME = {
   csymv_L_BULLDOZER, csymv_U_BULLDOZER,
   chemv_L_BULLDOZER, chemv_U_BULLDOZER, chemv_M_BULLDOZER, chemv_V_BULLDOZER,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   cgemm_kernel_n_BULLDOZER, cgemm_kernel_l_BULLDOZER, cgemm_kernel_r_BULLDOZER, cgemm_kernel_b_BULLDOZER,
   cgemm_beta_BULLDOZER,
 #if CGEMM_DEFAULT_UNROLL_M != CGEMM_DEFAULT_UNROLL_N
@@ -432,6 +446,7 @@ gotoblas_t TABLE_NAME = {
   ctrsm_ounucopy_BULLDOZER,  ctrsm_ounncopy_BULLDOZER,  ctrsm_outucopy_BULLDOZER,  ctrsm_outncopy_BULLDOZER,
   ctrsm_olnucopy_BULLDOZER,  ctrsm_olnncopy_BULLDOZER,  ctrsm_oltucopy_BULLDOZER,  ctrsm_oltncopy_BULLDOZER,
 #endif
+#endif
 #if (BUILD_COMPLEX)
 
   ctrmm_kernel_RN_BULLDOZER,  ctrmm_kernel_RT_BULLDOZER,  ctrmm_kernel_RR_BULLDOZER,  ctrmm_kernel_RC_BULLDOZER,
@@ -522,7 +537,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
 #ifndef NO_LAPACK
   cneg_tcopy_BULLDOZER,
   
@@ -866,7 +881,7 @@ gotoblas_t TABLE_NAME = {
   cgeadd_k_BULLDOZER,
 #endif
 #if BUILD_COMPLEX16==1
-  zgeadd_k_BULLDOZER
+  zgeadd_k_BULLDOZER,
 #endif
 };
 
@@ -878,7 +893,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX==1
@@ -891,10 +906,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_q = SBGEMM_DEFAULT_Q;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_q = SGEMM_DEFAULT_Q;
 #endif
-#if BUILD_DOUBLE== 1
+#if BUILD_DOUBLE== 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_q = DGEMM_DEFAULT_Q;
 #endif
 #if BUILD_COMPLEX== 1
@@ -907,10 +922,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_r = SBGEMM_DEFAULT_R;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_r = SGEMM_DEFAULT_R;
 #endif
-#if BUILD_DOUBLE==1 
+#if BUILD_DOUBLE==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_r = DGEMM_DEFAULT_R;
 #endif
 #if BUILD_COMPLEX==1
@@ -1313,7 +1328,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  64 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  32 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1337,7 +1352,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  96 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  48 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1361,7 +1376,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 256;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 128;
 #endif
 #if BUILD_COMPLEX==1
@@ -1385,7 +1400,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE ==1 
+#if BUILD_DOUBLE ==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1
@@ -1409,7 +1424,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  92 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE==1
+#if BUILD_DOUBLE==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  46 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1433,7 +1448,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1457,7 +1472,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1482,7 +1497,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1506,7 +1521,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1554,7 +1569,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1579,7 +1594,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 224 +  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 112 +  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX
@@ -1603,7 +1618,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1627,7 +1642,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1651,7 +1666,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1675,7 +1690,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1700,7 +1715,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1724,7 +1739,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1748,7 +1763,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1773,7 +1788,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if  (BUILD_DOUBLE==1)
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if (BUILD_COMPLEX==1)
