@@ -62,6 +62,8 @@ gotoblas_t TABLE_NAME = {
  MAX(SBGEMM_DEFAULT_UNROLL_M, SBGEMM_DEFAULT_UNROLL_N),
 #endif
 
+  SBGEMM_ALIGN_K,
+
   sbstobf16_k_EXCAVATOR, sbdtobf16_k_EXCAVATOR, sbf16tos_k_EXCAVATOR, dbf16tod_k_EXCAVATOR,
 
   samax_k_EXCAVATOR,  samin_k_EXCAVATOR,  smax_k_EXCAVATOR,  smin_k_EXCAVATOR,
@@ -135,9 +137,14 @@ gotoblas_t TABLE_NAME = {
   0,
 #endif
 
-#if (BUILD_SINGLE==1 ) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
   samax_k_EXCAVATOR,  samin_k_EXCAVATOR,  smax_k_EXCAVATOR,  smin_k_EXCAVATOR,
-  isamax_k_EXCAVATOR, isamin_k_EXCAVATOR, ismax_k_EXCAVATOR, ismin_k_EXCAVATOR,
+#endif
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+  isamax_k_EXCAVATOR,
+#endif 
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
+  isamin_k_EXCAVATOR, ismax_k_EXCAVATOR, ismin_k_EXCAVATOR,
   snrm2_k_EXCAVATOR,  sasum_k_EXCAVATOR,
 #endif 
 #if BUILD_SINGLE == 1  
@@ -156,8 +163,10 @@ gotoblas_t TABLE_NAME = {
   sswap_k_EXCAVATOR,
   sgemv_n_EXCAVATOR,  sgemv_t_EXCAVATOR,
 #endif
-#if BUILD_SINGLE == 1  
+#if BUILD_SINGLE == 1
   sger_k_EXCAVATOR,
+#endif
+#if BUILD_SINGLE == 1  
   ssymv_L_EXCAVATOR, ssymv_U_EXCAVATOR,
 #endif
 
@@ -176,7 +185,7 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_EXCAVATOR, sgemm_otcopy_EXCAVATOR,
 #endif
 
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || BUILD_DOUBLE == 1 || BUILD_COMPLEX == 1
 #ifdef SMALL_MATRIX_OPT
   sgemm_small_matrix_permit_EXCAVATOR,
   sgemm_small_kernel_nn_EXCAVATOR, sgemm_small_kernel_nt_EXCAVATOR, sgemm_small_kernel_tn_EXCAVATOR, sgemm_small_kernel_tt_EXCAVATOR,
@@ -184,7 +193,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX == 1)
   strsm_kernel_LN_EXCAVATOR, strsm_kernel_LT_EXCAVATOR, strsm_kernel_RN_EXCAVATOR, strsm_kernel_RT_EXCAVATOR,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strsm_iunucopy_EXCAVATOR, strsm_iunncopy_EXCAVATOR, strsm_iutucopy_EXCAVATOR, strsm_iutncopy_EXCAVATOR,
@@ -196,7 +205,7 @@ gotoblas_t TABLE_NAME = {
   strsm_ounucopy_EXCAVATOR, strsm_ounncopy_EXCAVATOR, strsm_outucopy_EXCAVATOR, strsm_outncopy_EXCAVATOR,
   strsm_olnucopy_EXCAVATOR, strsm_olnncopy_EXCAVATOR, strsm_oltucopy_EXCAVATOR, strsm_oltncopy_EXCAVATOR,
 #endif
-#if BUILD_SINGLE == 1
+#if (BUILD_SINGLE==1)
   strmm_kernel_RN_EXCAVATOR, strmm_kernel_RT_EXCAVATOR, strmm_kernel_LN_EXCAVATOR, strmm_kernel_LT_EXCAVATOR,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strmm_iunucopy_EXCAVATOR, strmm_iunncopy_EXCAVATOR, strmm_iutucopy_EXCAVATOR, strmm_iutncopy_EXCAVATOR,
@@ -213,8 +222,6 @@ gotoblas_t TABLE_NAME = {
   ssymm_outcopy_EXCAVATOR, ssymm_oltcopy_EXCAVATOR,
 #endif
   ssymm_outcopy_EXCAVATOR, ssymm_oltcopy_EXCAVATOR,
-#endif
-#if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)
 #ifndef NO_LAPACK
   sneg_tcopy_EXCAVATOR, slaswp_ncopy_EXCAVATOR,
 #else
@@ -222,7 +229,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   0, 0, 0,
   DGEMM_DEFAULT_UNROLL_M, DGEMM_DEFAULT_UNROLL_N,
 #ifdef DGEMM_DEFAULT_UNROLL_MN
@@ -233,7 +240,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   damax_k_EXCAVATOR,  damin_k_EXCAVATOR,  dmax_k_EXCAVATOR,  dmin_k_EXCAVATOR,
   idamax_k_EXCAVATOR, idamin_k_EXCAVATOR, idmax_k_EXCAVATOR, idmin_k_EXCAVATOR,
   dnrm2_k_EXCAVATOR, dasum_k_EXCAVATOR,
@@ -241,13 +248,13 @@ gotoblas_t TABLE_NAME = {
 #if  (BUILD_DOUBLE==1)  
   dsum_k_EXCAVATOR,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dcopy_k_EXCAVATOR, ddot_k_EXCAVATOR,
 #endif
 #if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)  
   dsdot_k_EXCAVATOR,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   drot_k_EXCAVATOR,
   daxpy_k_EXCAVATOR,
   dscal_k_EXCAVATOR, 
@@ -259,7 +266,7 @@ gotoblas_t TABLE_NAME = {
   dsymv_L_EXCAVATOR,  dsymv_U_EXCAVATOR,
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dgemm_kernel_EXCAVATOR, dgemm_beta_EXCAVATOR,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dgemm_incopy_EXCAVATOR, dgemm_itcopy_EXCAVATOR,
@@ -269,12 +276,14 @@ gotoblas_t TABLE_NAME = {
   dgemm_oncopy_EXCAVATOR, dgemm_otcopy_EXCAVATOR,
 #endif
 
-#if  (BUILD_DOUBLE==1)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
 #ifdef SMALL_MATRIX_OPT
   dgemm_small_matrix_permit_EXCAVATOR,
   dgemm_small_kernel_nn_EXCAVATOR, dgemm_small_kernel_nt_EXCAVATOR, dgemm_small_kernel_tn_EXCAVATOR, dgemm_small_kernel_tt_EXCAVATOR,
   dgemm_small_kernel_b0_nn_EXCAVATOR, dgemm_small_kernel_b0_nt_EXCAVATOR, dgemm_small_kernel_b0_tn_EXCAVATOR, dgemm_small_kernel_b0_tt_EXCAVATOR,
 #endif
+#endif
+#if  (BUILD_DOUBLE==1)   
   dtrsm_kernel_LN_EXCAVATOR, dtrsm_kernel_LT_EXCAVATOR, dtrsm_kernel_RN_EXCAVATOR, dtrsm_kernel_RT_EXCAVATOR,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_EXCAVATOR, dtrsm_iunncopy_EXCAVATOR, dtrsm_iutucopy_EXCAVATOR, dtrsm_iutncopy_EXCAVATOR,
@@ -364,7 +373,7 @@ gotoblas_t TABLE_NAME = {
 
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   0, 0, 0,
   CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N,
 #ifdef CGEMM_DEFAULT_UNROLL_MN
@@ -372,18 +381,23 @@ gotoblas_t TABLE_NAME = {
 #else
  MAX(CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N),
 #endif
-  camax_k_EXCAVATOR, camin_k_EXCAVATOR, icamax_k_EXCAVATOR, icamin_k_EXCAVATOR,
+#if (BUILD_COMPLEX)
+  camax_k_EXCAVATOR, camin_k_EXCAVATOR,
 #endif
 #if (BUILD_COMPLEX)
+  icamax_k_EXCAVATOR, 
+#endif
+#if (BUILD_COMPLEX)
+  icamin_k_EXCAVATOR,
   cnrm2_k_EXCAVATOR, casum_k_EXCAVATOR, csum_k_EXCAVATOR,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
-  ccopy_k_EXCAVATOR,  cdotu_k_EXCAVATOR, cdotc_k_EXCAVATOR,
+#if (BUILD_COMPLEX)
+  ccopy_k_EXCAVATOR, cdotu_k_EXCAVATOR, cdotc_k_EXCAVATOR,
 #endif
 #if (BUILD_COMPLEX)
  csrot_k_EXCAVATOR,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   caxpy_k_EXCAVATOR,
   caxpyc_k_EXCAVATOR, 
   cscal_k_EXCAVATOR, 
@@ -397,7 +411,7 @@ gotoblas_t TABLE_NAME = {
   csymv_L_EXCAVATOR, csymv_U_EXCAVATOR,
   chemv_L_EXCAVATOR, chemv_U_EXCAVATOR, chemv_M_EXCAVATOR, chemv_V_EXCAVATOR,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   cgemm_kernel_n_EXCAVATOR, cgemm_kernel_l_EXCAVATOR, cgemm_kernel_r_EXCAVATOR, cgemm_kernel_b_EXCAVATOR,
   cgemm_beta_EXCAVATOR,
 #if CGEMM_DEFAULT_UNROLL_M != CGEMM_DEFAULT_UNROLL_N
@@ -432,6 +446,7 @@ gotoblas_t TABLE_NAME = {
   ctrsm_ounucopy_EXCAVATOR,  ctrsm_ounncopy_EXCAVATOR,  ctrsm_outucopy_EXCAVATOR,  ctrsm_outncopy_EXCAVATOR,
   ctrsm_olnucopy_EXCAVATOR,  ctrsm_olnncopy_EXCAVATOR,  ctrsm_oltucopy_EXCAVATOR,  ctrsm_oltncopy_EXCAVATOR,
 #endif
+#endif
 #if (BUILD_COMPLEX)
 
   ctrmm_kernel_RN_EXCAVATOR,  ctrmm_kernel_RT_EXCAVATOR,  ctrmm_kernel_RR_EXCAVATOR,  ctrmm_kernel_RC_EXCAVATOR,
@@ -522,7 +537,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
 #ifndef NO_LAPACK
   cneg_tcopy_EXCAVATOR,
   
@@ -866,7 +881,7 @@ gotoblas_t TABLE_NAME = {
   cgeadd_k_EXCAVATOR,
 #endif
 #if BUILD_COMPLEX16==1
-  zgeadd_k_EXCAVATOR
+  zgeadd_k_EXCAVATOR,
 #endif
 };
 
@@ -878,7 +893,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX==1
@@ -891,10 +906,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_q = SBGEMM_DEFAULT_Q;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_q = SGEMM_DEFAULT_Q;
 #endif
-#if BUILD_DOUBLE== 1
+#if BUILD_DOUBLE== 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_q = DGEMM_DEFAULT_Q;
 #endif
 #if BUILD_COMPLEX== 1
@@ -907,10 +922,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_r = SBGEMM_DEFAULT_R;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_r = SGEMM_DEFAULT_R;
 #endif
-#if BUILD_DOUBLE==1 
+#if BUILD_DOUBLE==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_r = DGEMM_DEFAULT_R;
 #endif
 #if BUILD_COMPLEX==1
@@ -1313,7 +1328,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  64 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  32 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1337,7 +1352,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  96 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  48 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1361,7 +1376,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 256;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 128;
 #endif
 #if BUILD_COMPLEX==1
@@ -1385,7 +1400,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE ==1 
+#if BUILD_DOUBLE ==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1
@@ -1409,7 +1424,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  92 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE==1
+#if BUILD_DOUBLE==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  46 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1433,7 +1448,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1457,7 +1472,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1482,7 +1497,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1506,7 +1521,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1554,7 +1569,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1579,7 +1594,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 224 +  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 112 +  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX
@@ -1603,7 +1618,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1627,7 +1642,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1651,7 +1666,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1675,7 +1690,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1700,7 +1715,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1724,7 +1739,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1748,7 +1763,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1773,7 +1788,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if  (BUILD_DOUBLE==1)
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if (BUILD_COMPLEX==1)
