@@ -62,6 +62,8 @@ gotoblas_t TABLE_NAME = {
  MAX(SBGEMM_DEFAULT_UNROLL_M, SBGEMM_DEFAULT_UNROLL_N),
 #endif
 
+  SBGEMM_ALIGN_K,
+
   sbstobf16_k_HASWELL, sbdtobf16_k_HASWELL, sbf16tos_k_HASWELL, dbf16tod_k_HASWELL,
 
   samax_k_HASWELL,  samin_k_HASWELL,  smax_k_HASWELL,  smin_k_HASWELL,
@@ -135,9 +137,14 @@ gotoblas_t TABLE_NAME = {
   0,
 #endif
 
-#if (BUILD_SINGLE==1 ) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
   samax_k_HASWELL,  samin_k_HASWELL,  smax_k_HASWELL,  smin_k_HASWELL,
-  isamax_k_HASWELL, isamin_k_HASWELL, ismax_k_HASWELL, ismin_k_HASWELL,
+#endif
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX==1)
+  isamax_k_HASWELL,
+#endif 
+#if (BUILD_SINGLE==1 ) || (BUILD_COMPLEX==1)
+  isamin_k_HASWELL, ismax_k_HASWELL, ismin_k_HASWELL,
   snrm2_k_HASWELL,  sasum_k_HASWELL,
 #endif 
 #if BUILD_SINGLE == 1  
@@ -156,8 +163,10 @@ gotoblas_t TABLE_NAME = {
   sswap_k_HASWELL,
   sgemv_n_HASWELL,  sgemv_t_HASWELL,
 #endif
-#if BUILD_SINGLE == 1  
+#if BUILD_SINGLE == 1
   sger_k_HASWELL,
+#endif
+#if BUILD_SINGLE == 1  
   ssymv_L_HASWELL, ssymv_U_HASWELL,
 #endif
 
@@ -176,7 +185,7 @@ gotoblas_t TABLE_NAME = {
   sgemm_oncopy_HASWELL, sgemm_otcopy_HASWELL,
 #endif
 
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || BUILD_DOUBLE == 1 || BUILD_COMPLEX == 1
 #ifdef SMALL_MATRIX_OPT
   sgemm_small_matrix_permit_HASWELL,
   sgemm_small_kernel_nn_HASWELL, sgemm_small_kernel_nt_HASWELL, sgemm_small_kernel_tn_HASWELL, sgemm_small_kernel_tt_HASWELL,
@@ -184,7 +193,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) 
+#if (BUILD_SINGLE==1) || (BUILD_DOUBLE==1) || (BUILD_COMPLEX == 1)
   strsm_kernel_LN_HASWELL, strsm_kernel_LT_HASWELL, strsm_kernel_RN_HASWELL, strsm_kernel_RT_HASWELL,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strsm_iunucopy_HASWELL, strsm_iunncopy_HASWELL, strsm_iutucopy_HASWELL, strsm_iutncopy_HASWELL,
@@ -196,7 +205,7 @@ gotoblas_t TABLE_NAME = {
   strsm_ounucopy_HASWELL, strsm_ounncopy_HASWELL, strsm_outucopy_HASWELL, strsm_outncopy_HASWELL,
   strsm_olnucopy_HASWELL, strsm_olnncopy_HASWELL, strsm_oltucopy_HASWELL, strsm_oltncopy_HASWELL,
 #endif
-#if BUILD_SINGLE == 1
+#if (BUILD_SINGLE==1)
   strmm_kernel_RN_HASWELL, strmm_kernel_RT_HASWELL, strmm_kernel_LN_HASWELL, strmm_kernel_LT_HASWELL,
 #if SGEMM_DEFAULT_UNROLL_M != SGEMM_DEFAULT_UNROLL_N
   strmm_iunucopy_HASWELL, strmm_iunncopy_HASWELL, strmm_iutucopy_HASWELL, strmm_iutncopy_HASWELL,
@@ -213,8 +222,6 @@ gotoblas_t TABLE_NAME = {
   ssymm_outcopy_HASWELL, ssymm_oltcopy_HASWELL,
 #endif
   ssymm_outcopy_HASWELL, ssymm_oltcopy_HASWELL,
-#endif
-#if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)
 #ifndef NO_LAPACK
   sneg_tcopy_HASWELL, slaswp_ncopy_HASWELL,
 #else
@@ -222,7 +229,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   0, 0, 0,
   DGEMM_DEFAULT_UNROLL_M, DGEMM_DEFAULT_UNROLL_N,
 #ifdef DGEMM_DEFAULT_UNROLL_MN
@@ -233,7 +240,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   damax_k_HASWELL,  damin_k_HASWELL,  dmax_k_HASWELL,  dmin_k_HASWELL,
   idamax_k_HASWELL, idamin_k_HASWELL, idmax_k_HASWELL, idmin_k_HASWELL,
   dnrm2_k_HASWELL, dasum_k_HASWELL,
@@ -241,13 +248,13 @@ gotoblas_t TABLE_NAME = {
 #if  (BUILD_DOUBLE==1)  
   dsum_k_HASWELL,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dcopy_k_HASWELL, ddot_k_HASWELL,
 #endif
 #if  (BUILD_SINGLE==1) || (BUILD_DOUBLE==1)  
   dsdot_k_HASWELL,
 #endif
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   drot_k_HASWELL,
   daxpy_k_HASWELL,
   dscal_k_HASWELL, 
@@ -259,7 +266,7 @@ gotoblas_t TABLE_NAME = {
   dsymv_L_HASWELL,  dsymv_U_HASWELL,
 #endif
 
-#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
   dgemm_kernel_HASWELL, dgemm_beta_HASWELL,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dgemm_incopy_HASWELL, dgemm_itcopy_HASWELL,
@@ -269,12 +276,14 @@ gotoblas_t TABLE_NAME = {
   dgemm_oncopy_HASWELL, dgemm_otcopy_HASWELL,
 #endif
 
-#if  (BUILD_DOUBLE==1)  
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)  
 #ifdef SMALL_MATRIX_OPT
   dgemm_small_matrix_permit_HASWELL,
   dgemm_small_kernel_nn_HASWELL, dgemm_small_kernel_nt_HASWELL, dgemm_small_kernel_tn_HASWELL, dgemm_small_kernel_tt_HASWELL,
   dgemm_small_kernel_b0_nn_HASWELL, dgemm_small_kernel_b0_nt_HASWELL, dgemm_small_kernel_b0_tn_HASWELL, dgemm_small_kernel_b0_tt_HASWELL,
 #endif
+#endif
+#if  (BUILD_DOUBLE==1)   
   dtrsm_kernel_LN_HASWELL, dtrsm_kernel_LT_HASWELL, dtrsm_kernel_RN_HASWELL, dtrsm_kernel_RT_HASWELL,
 #if DGEMM_DEFAULT_UNROLL_M != DGEMM_DEFAULT_UNROLL_N
   dtrsm_iunucopy_HASWELL, dtrsm_iunncopy_HASWELL, dtrsm_iutucopy_HASWELL, dtrsm_iutncopy_HASWELL,
@@ -364,7 +373,7 @@ gotoblas_t TABLE_NAME = {
 
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   0, 0, 0,
   CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N,
 #ifdef CGEMM_DEFAULT_UNROLL_MN
@@ -372,18 +381,23 @@ gotoblas_t TABLE_NAME = {
 #else
  MAX(CGEMM_DEFAULT_UNROLL_M, CGEMM_DEFAULT_UNROLL_N),
 #endif
-  camax_k_HASWELL, camin_k_HASWELL, icamax_k_HASWELL, icamin_k_HASWELL,
+#if (BUILD_COMPLEX)
+  camax_k_HASWELL, camin_k_HASWELL,
 #endif
 #if (BUILD_COMPLEX)
+  icamax_k_HASWELL, 
+#endif
+#if (BUILD_COMPLEX)
+  icamin_k_HASWELL,
   cnrm2_k_HASWELL, casum_k_HASWELL, csum_k_HASWELL,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
-  ccopy_k_HASWELL,  cdotu_k_HASWELL, cdotc_k_HASWELL,
+#if (BUILD_COMPLEX)
+  ccopy_k_HASWELL, cdotu_k_HASWELL, cdotc_k_HASWELL,
 #endif
 #if (BUILD_COMPLEX)
  csrot_k_HASWELL,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   caxpy_k_HASWELL,
   caxpyc_k_HASWELL, 
   cscal_k_HASWELL, 
@@ -397,7 +411,7 @@ gotoblas_t TABLE_NAME = {
   csymv_L_HASWELL, csymv_U_HASWELL,
   chemv_L_HASWELL, chemv_U_HASWELL, chemv_M_HASWELL, chemv_V_HASWELL,
 #endif
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
   cgemm_kernel_n_HASWELL, cgemm_kernel_l_HASWELL, cgemm_kernel_r_HASWELL, cgemm_kernel_b_HASWELL,
   cgemm_beta_HASWELL,
 #if CGEMM_DEFAULT_UNROLL_M != CGEMM_DEFAULT_UNROLL_N
@@ -432,6 +446,7 @@ gotoblas_t TABLE_NAME = {
   ctrsm_ounucopy_HASWELL,  ctrsm_ounncopy_HASWELL,  ctrsm_outucopy_HASWELL,  ctrsm_outncopy_HASWELL,
   ctrsm_olnucopy_HASWELL,  ctrsm_olnncopy_HASWELL,  ctrsm_oltucopy_HASWELL,  ctrsm_oltncopy_HASWELL,
 #endif
+#endif
 #if (BUILD_COMPLEX)
 
   ctrmm_kernel_RN_HASWELL,  ctrmm_kernel_RT_HASWELL,  ctrmm_kernel_RR_HASWELL,  ctrmm_kernel_RC_HASWELL,
@@ -522,7 +537,7 @@ gotoblas_t TABLE_NAME = {
 #endif
 #endif
 
-#if (BUILD_COMPLEX || BUILD_COMPLEX16)
+#if (BUILD_COMPLEX)
 #ifndef NO_LAPACK
   cneg_tcopy_HASWELL,
   
@@ -866,7 +881,7 @@ gotoblas_t TABLE_NAME = {
   cgeadd_k_HASWELL,
 #endif
 #if BUILD_COMPLEX16==1
-  zgeadd_k_HASWELL
+  zgeadd_k_HASWELL,
 #endif
 };
 
@@ -878,7 +893,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX==1
@@ -891,10 +906,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_q = SBGEMM_DEFAULT_Q;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_q = SGEMM_DEFAULT_Q;
 #endif
-#if BUILD_DOUBLE== 1
+#if BUILD_DOUBLE== 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_q = DGEMM_DEFAULT_Q;
 #endif
 #if BUILD_COMPLEX== 1
@@ -907,10 +922,10 @@ static void init_parameter(void) {
 #if (BUILD_BFLOAT16)
   TABLE_NAME.sbgemm_r = SBGEMM_DEFAULT_R;
 #endif
-#if BUILD_SINGLE == 1
+#if BUILD_SINGLE == 1 || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_r = SGEMM_DEFAULT_R;
 #endif
-#if BUILD_DOUBLE==1 
+#if BUILD_DOUBLE==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_r = DGEMM_DEFAULT_R;
 #endif
 #if BUILD_COMPLEX==1
@@ -1313,7 +1328,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  64 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  32 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1337,7 +1352,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  96 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  48 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1 
@@ -1361,7 +1376,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 256;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 128;
 #endif
 #if BUILD_COMPLEX==1
@@ -1385,7 +1400,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE ==1 
+#if BUILD_DOUBLE ==1  || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX==1
@@ -1409,7 +1424,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  92 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE==1
+#if BUILD_DOUBLE==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  46 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1433,7 +1448,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE == 1
+#if BUILD_DOUBLE == 1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1457,7 +1472,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p =  42 * (l2 >> 9) + 8;
 #endif
-#if BUILD_DOUBLE ==1
+#if BUILD_DOUBLE ==1 || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p =  42 * (l2 >> 9) + 8;
 #endif
 #if BUILD_COMPLEX==1
@@ -1482,7 +1497,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1506,7 +1521,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1554,7 +1569,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1579,7 +1594,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = 224 +  56 * (l2 >> 7);
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = 112 +  28 * (l2 >> 7);
 #endif
 #if BUILD_COMPLEX
@@ -1603,7 +1618,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1627,7 +1642,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1651,7 +1666,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1675,7 +1690,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1700,7 +1715,7 @@ static void init_parameter(void) {
 #if (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1724,7 +1739,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if BUILD_DOUBLE || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1748,7 +1763,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if BUILD_DOUBLE
+#if (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if BUILD_COMPLEX
@@ -1773,7 +1788,7 @@ static void init_parameter(void) {
 #if  (BUILD_SINGLE==1) || (BUILD_COMPLEX==1)
   TABLE_NAME.sgemm_p = SGEMM_DEFAULT_P;
 #endif
-#if  (BUILD_DOUBLE==1)
+#if  (BUILD_DOUBLE==1) || (BUILD_COMPLEX16==1)
   TABLE_NAME.dgemm_p = DGEMM_DEFAULT_P;
 #endif
 #if (BUILD_COMPLEX==1)
